@@ -1,6 +1,8 @@
 /*
  * LapisPuzzleView.m
-
+ 
+ * Copyright 2004-2011 The Free Software Foundation
+ * 
  * Copyright (C) 2004 Banlu Kemiyatorn.
  * July 19, 2004
  * Written by Banlu Kemiyatorn <object at gmail dot com>
@@ -19,8 +21,8 @@
  * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA.
  */
 
-#include "LapisPuzzleView.h"
-#include "LPController.h"
+#import "LapisPuzzleView.h"
+#import "LPController.h"
 #include <math.h>
 
 static float _grid_height;
@@ -61,12 +63,9 @@ static float _grid_height;
 
 - (void) setAlpha:(float)a
 {
-	if (a < 0)
-	{
-		a = 0;
-		return;
-	}
-	alpha = a;
+  if (a < 0)
+    a = 0;
+  alpha = a;
 }
 
 - (LPUnitColorType) unitColor
@@ -170,11 +169,12 @@ static float _grid_height;
 
 - (BOOL) moveInDir:(LPDirType)dir
 {
+  return NO;
 }
 
-- (BOOL) rMoveX:(int)rx
-			  Y:(int)ry
+- (BOOL) rMoveX:(int)rx Y:(int)ry
 {
+  return NO;
 }
 
 - (void) changePhase
@@ -183,14 +183,17 @@ static float _grid_height;
 
 - (int) X
 {
+  return 0;
 }
 
 - (int) Y
 {
+  return 0;
 }
 
 - (float) phase
 {
+  return 0.0;
 }
 
 - (void) explode
@@ -205,17 +208,18 @@ static float _grid_height;
 {
 }
 
-- (void) setX:(unsigned int)x
-			Y:(unsigned int)y
+- (void) setX:(unsigned int)x Y:(unsigned int)y
 {
 }
 
 - (BOOL) canMoveInDir:(LPDirType)dir
 {
+  return NO;
 }
-- (BOOL) canRMoveX:(int)rx
-				 Y:(int)ry
+
+- (BOOL) canRMoveX:(int)rx Y:(int)ry
 {
+  return NO;
 }
 
 @end
@@ -247,8 +251,13 @@ static float _grid_height;
 
 - (void) draw
 {
+	int i;
+	NSColor *tcolor;
+	NSMutableAttributedString *str;
+	NSSize strSize;
 	NSSize gz = [__owner gridSize];
 	float border = gz.width/6;
+
 	[super draw];
 
 	PSsetrgbcolor(0.7,0.7,0.7);
@@ -272,7 +281,6 @@ static float _grid_height;
 	PSlineto((_x+_columns) * gz.width, (_y+_rows) * gz.height);
 	PSfill();
 
-	int i;
 	for (i = 0; i <_rows; i+=2)
 	{
 		PSgsave();
@@ -321,9 +329,6 @@ static float _grid_height;
 
 
 	/****/
-	NSColor *tcolor;
-	NSMutableAttributedString *str;
-	NSSize strSize;
 
 	PSsetrgbcolor(0,0,0);
 	PSsetalpha(0.8);
@@ -790,46 +795,46 @@ static float _grid_height;
 
 - (BOOL) canMoveInDir:(LPDirType)dir
 {
-	id en;
-	LPUnit* unit;
+  int cx,cy;
 
-	int cx,cy;
-
-	switch(dir)
+  switch(dir)
+    {
+    case LP_MOVE_LEFT:
+      if (_x == 0)
 	{
-		case LP_MOVE_LEFT:
-			if (_x == 0)
-			{
-				return NO;
-			}
-			cx = -1;
-			cy = 0;
-			break;
-		case LP_MOVE_DOWN:
-			if (_y == 0)
-			{
-				return NO;
-			}
-			cx = 0;
-			cy = -1;
-			break;
-		case LP_MOVE_RIGHT:
-			if (_x == 5)
-			{
-				return NO;
-			}
-			cx = 1;
-			cy = 0;
-			break;
-		case LP_MOVE_UP:
-			/* no check for upper border */
-			cx = 0;
-			cy = 1;
-			break;
+	  return NO;
 	}
+      cx = -1;
+      cy = 0;
+      break;
+    case LP_MOVE_DOWN:
+      if (_y == 0)
+	{
+	  return NO;
+	}
+      cx = 0;
+      cy = -1;
+      break;
+    case LP_MOVE_RIGHT:
+      if (_x == 5)
+	{
+	  return NO;
+	}
+      cx = 1;
+      cy = 0;
+      break;
+    case LP_MOVE_UP:
+      /* no check for upper border */
+      cx = 0;
+      cy = 1;
+      break;
+    default:
+      NSAssert(0, @"Unreachable");
+      return NO;
+      break;
+    }
 
-	return [self canRMoveX:cx
-						 Y:cy];
+  return [self canRMoveX:cx Y:cy];
 }
 
 - (BOOL) rMoveX:(int)rx
@@ -848,26 +853,30 @@ static float _grid_height;
 
 - (BOOL) moveInDir:(LPDirType)dir
 {
-	if (![self canMoveInDir:dir])
-	{
-		return NO;
-	}
-	switch(dir)
-	{
-		case LP_MOVE_DOWN:
-			_y--;
-			break;
-		case LP_MOVE_LEFT:
-			_x--;
-			break;
-		case LP_MOVE_UP:
-			_y++;
-			break;
-		case LP_MOVE_RIGHT:
-			_x++;
-			break;
-	}
-	return YES;
+  if (![self canMoveInDir:dir])
+    {
+      return NO;
+    }
+  switch(dir)
+    {
+    case LP_MOVE_DOWN:
+      _y--;
+      break;
+    case LP_MOVE_LEFT:
+      _x--;
+      break;
+    case LP_MOVE_UP:
+      _y++;
+      break;
+    case LP_MOVE_RIGHT:
+      _x++;
+      break;
+    default:
+      NSAssert(0, @"Unreachable");
+      break;
+
+    }
+  return YES;
 }
 
 - (BOOL) hasPartAtX:(int)x
@@ -928,103 +937,109 @@ static float _grid_height;
 
 - (void) rotateCCW
 {
-	id move = [_units objectAtIndex:0];
-	id base = [_units objectAtIndex:1];
+  id move = [_units objectAtIndex:0];
+  id base = [_units objectAtIndex:1];
 
-	switch(_laydir)
+  switch(_laydir)
+    {
+    case LP_MOVE_DOWN:
+      if ([move rMoveX:-1
+		     Y:-1])
 	{
-		case LP_MOVE_DOWN:
-			if ([move rMoveX:-1
-						   Y:-1])
-			{
-				_laydir = LP_MOVE_LEFT;
-			}
-			else if ([base canRMoveX:1 Y:0])
-			{
-				[base rMoveX:1 Y:0];
-				[move rMoveX:0 Y:-1];
-				_laydir = LP_MOVE_LEFT;
-			}
-		break;
-		case LP_MOVE_LEFT:
-			if ([move rMoveX:1
-						   Y:-1])
-			{
-				_laydir = LP_MOVE_UP;
-			}
-		break;
-		case LP_MOVE_UP:
-			if ([move rMoveX:1
-						   Y:1])
-			{
-				_laydir = LP_MOVE_RIGHT;
-			}
-			else if ([base canRMoveX:-1 Y:0])
-			{
-				[base rMoveX:-1 Y:0];
-				[move rMoveX:0 Y:1];
-				_laydir = LP_MOVE_RIGHT;
-			}
-		break;
-		case LP_MOVE_RIGHT:
-			if ([move rMoveX:-1
-						   Y:1])
-			{
-				_laydir = LP_MOVE_DOWN;
-			}
-		break;
+	  _laydir = LP_MOVE_LEFT;
 	}
+      else if ([base canRMoveX:1 Y:0])
+	{
+	  [base rMoveX:1 Y:0];
+	  [move rMoveX:0 Y:-1];
+	  _laydir = LP_MOVE_LEFT;
+	}
+      break;
+    case LP_MOVE_LEFT:
+      if ([move rMoveX:1
+		     Y:-1])
+	{
+	  _laydir = LP_MOVE_UP;
+	}
+      break;
+    case LP_MOVE_UP:
+      if ([move rMoveX:1
+		     Y:1])
+	{
+	  _laydir = LP_MOVE_RIGHT;
+	}
+      else if ([base canRMoveX:-1 Y:0])
+	{
+	  [base rMoveX:-1 Y:0];
+	  [move rMoveX:0 Y:1];
+	  _laydir = LP_MOVE_RIGHT;
+	}
+      break;
+    case LP_MOVE_RIGHT:
+      if ([move rMoveX:-1
+		     Y:1])
+	{
+	  _laydir = LP_MOVE_DOWN;
+	}
+      break;
+    default:
+      NSAssert(0, @"Unreachable");
+      break;
+    }
 
 }
 
 - (void) rotateCW
 {
-	id move = [_units objectAtIndex:0];
-	id base = [_units objectAtIndex:1];
+  id move = [_units objectAtIndex:0];
+  id base = [_units objectAtIndex:1];
 
-	switch(_laydir)
+  switch(_laydir)
+    {
+    case LP_MOVE_DOWN:
+      if ([move rMoveX:1 // should physically block rotation?
+		     Y:-1])
 	{
-		case LP_MOVE_DOWN:
-			if ([move rMoveX:1 // should physically block rotation?
-						   Y:-1])
-			{
-				_laydir = LP_MOVE_RIGHT;
-			}
-			else if ([base canRMoveX:-1 Y:0])
-			{
-				[base rMoveX:-1 Y:0];
-				[move rMoveX:0 Y:-1];
-				_laydir = LP_MOVE_RIGHT;
-			}
-		break;
-		case LP_MOVE_RIGHT:
-			if ([move rMoveX:-1
-						   Y:-1])
-			{
-				_laydir = LP_MOVE_UP;
-			}
-		break;
-		case LP_MOVE_UP:
-			if ([move rMoveX:-1
-						   Y:1])
-			{
-				_laydir = LP_MOVE_LEFT;
-			}
-			else if ([base canRMoveX:1 Y:0])
-			{
-				[base rMoveX:1 Y:0];
-				[move rMoveX:0 Y:1];
-				_laydir = LP_MOVE_LEFT;
-			}
-		break;
-		case LP_MOVE_LEFT:
-			if ([move rMoveX:1
-						   Y:1])
-			{
-				_laydir = LP_MOVE_DOWN;
-			}
-		break;
+	  _laydir = LP_MOVE_RIGHT;
 	}
+      else if ([base canRMoveX:-1 Y:0])
+	{
+	  [base rMoveX:-1 Y:0];
+	  [move rMoveX:0 Y:-1];
+	  _laydir = LP_MOVE_RIGHT;
+	}
+      break;
+    case LP_MOVE_RIGHT:
+      if ([move rMoveX:-1
+		     Y:-1])
+	{
+	  _laydir = LP_MOVE_UP;
+	}
+      break;
+    case LP_MOVE_UP:
+      if ([move rMoveX:-1
+		     Y:1])
+	{
+	  _laydir = LP_MOVE_LEFT;
+	}
+      else if ([base canRMoveX:1 Y:0])
+	{
+	  [base rMoveX:1 Y:0];
+	  [move rMoveX:0 Y:1];
+	  _laydir = LP_MOVE_LEFT;
+	}
+      break;
+    case LP_MOVE_LEFT:
+      if ([move rMoveX:1
+		     Y:1])
+	{
+	  _laydir = LP_MOVE_DOWN;
+	}
+      break;
+    default:
+      NSAssert(0, @"Unreachable");
+      break;
+    }
 
 }
 
@@ -1072,6 +1087,7 @@ static float _grid_height;
 
 - (int) Y
 {
+  return 0;
 }
 
 - (void) dealloc
@@ -1102,7 +1118,6 @@ static float _grid_height;
 {
 	id en;
 	LPUnit* unit;
-	BOOL canMove = YES;
 
 	en = [_units objectEnumerator];
 	while ((unit = [en nextObject]))
@@ -1159,8 +1174,7 @@ static float _grid_height;
 {
 	id en;
 	LPUnit* unit;
-	BOOL canMove = YES;
-
+ 
 	en = [_units objectEnumerator];
 	while ((unit = [en nextObject]))
 	{
@@ -1294,10 +1308,10 @@ static LPUnit * _random_unit(id owner, int x, int y, BOOL diamond)
 	{
 		if (__currentUnit)
 		{
-			_lockControl = YES;
 			/* replace timer stone with jewel */
-
 			NSMutableArray *ar;
+
+			_lockControl = YES;
 			ar = [NSMutableArray array];
 			en = [_units objectEnumerator];
 			while ((unit = [en nextObject]))
@@ -1322,6 +1336,7 @@ static LPUnit * _random_unit(id owner, int x, int y, BOOL diamond)
 													   Y:[unit Y]];
 				[_units removeObject:unit];
 				[_units addObject:new];
+				[new release];
 			}
 
 
@@ -1439,6 +1454,7 @@ static LPUnit * _random_unit(id owner, int x, int y, BOOL diamond)
 	id en;
 	LPJewelUnit* unit;
 	int i,j;
+	BOOL merge;
 
 
 	id m1,m2,m3;
@@ -1483,7 +1499,6 @@ static LPUnit * _random_unit(id owner, int x, int y, BOOL diamond)
 		}
 	}
 
-	BOOL merge;
 	do
 	{
 		merge = NO;
@@ -1497,6 +1512,8 @@ static LPUnit * _random_unit(id owner, int x, int y, BOOL diamond)
 
 			if (unit_rows >= 2)
 			{
+				NSMutableArray *ar = [NSMutableArray array];
+
 				color = [unit unitColor];
 				unit_x = [unit X];
 				unit_y = [unit Y];
@@ -1529,7 +1546,6 @@ static LPUnit * _random_unit(id owner, int x, int y, BOOL diamond)
 
 
 				/* check right side */
-				NSMutableArray *ar = [NSMutableArray array];
 				for (i = 0; i < unit_rows; i++)
 				{
 					m1 = [self getUnitAtX:unit_x + unit_columns
@@ -1542,8 +1558,9 @@ static LPUnit * _random_unit(id owner, int x, int y, BOOL diamond)
 				}
 				if ([ar count] == unit_rows)
 				{
-					merge = YES;
 					id en2, unit2;
+
+					merge = YES;
 					en2 = [ar objectEnumerator];
 					while ((unit2 = [en2 nextObject]))
 					{
@@ -1567,8 +1584,9 @@ static LPUnit * _random_unit(id owner, int x, int y, BOOL diamond)
 				}
 				if ([ar count] == unit_rows)
 				{
-					merge = YES;
 					id en2, unit2;
+
+					merge = YES;
 					en2 = [ar objectEnumerator];
 					while ((unit2 = [en2 nextObject]))
 					{
@@ -1593,8 +1611,9 @@ static LPUnit * _random_unit(id owner, int x, int y, BOOL diamond)
 				}
 				if ([ar count] == unit_columns)
 				{
-					merge = YES;
 					id en2, unit2;
+
+					merge = YES;
 					en2 = [ar objectEnumerator];
 					while ((unit2 = [en2 nextObject]))
 					{
@@ -1618,8 +1637,9 @@ static LPUnit * _random_unit(id owner, int x, int y, BOOL diamond)
 				}
 				if ([ar count] == unit_columns)
 				{
-					merge = YES;
 					id en2, unit2;
+
+					merge = YES;
 					en2 = [ar objectEnumerator];
 					while ((unit2 = [en2 nextObject]))
 					{
@@ -1815,7 +1835,7 @@ static LPUnit * _random_unit(id owner, int x, int y, BOOL diamond)
 	{
 		int cc,xx,yy;
 		LPUnit* unit;
-		cc=xx=yy=0;
+		cc=0;
 
 		for (yy = 13; yy >= 0 && cc < 8; yy--)
 		for (xx = 5; xx >= 0; xx--)
@@ -1894,6 +1914,9 @@ static LPUnit * _random_unit(id owner, int x, int y, BOOL diamond)
 - (void) drawRect:(NSRect)r
 {
 	int i;
+	id en;
+	LPUnit *unit;
+
 	/*
 	[_background compositeToPoint:NSZeroPoint
 						operation:NSCompositeCopy];
@@ -1921,9 +1944,6 @@ static LPUnit * _random_unit(id owner, int x, int y, BOOL diamond)
 	}
 	PSstroke();
 
-	id en;
-	LPUnit *unit;
-
 	en = [_blowing objectEnumerator];
 	while ((unit = [en nextObject]))
 	{
@@ -1939,8 +1959,8 @@ static LPUnit * _random_unit(id owner, int x, int y, BOOL diamond)
 	{
 		int cc,xx,yy;
 		LPUnit* unit;
-		cc=xx=yy=0;
 		NSMutableSet *set = [NSMutableSet setWithCapacity:70];
+		cc=0;
 
 		for (yy = 13; yy >= 0 && cc < 8; yy--)
 		for (xx = 5; xx >= 0; xx--)
@@ -2066,40 +2086,43 @@ static LPUnit * _random_unit(id owner, int x, int y, BOOL diamond)
 
 -(BOOL) processDir:(LPDirType)dir
 {
-	if (_lockControl)
-	{
-		return NO;
-	}
-	if (__currentUnit == nil)
-	{
-		return NO;
-	}
-	switch(dir)
-	{
-		case LP_MOVE_DOWN:
- 			return [__currentUnit moveInDir:LP_MOVE_DOWN];
-			break;
-		case LP_MOVE_LEFT:
-			return [__currentUnit moveInDir:LP_MOVE_LEFT];
-			break;
-		case LP_MOVE_RIGHT:
-			return [__currentUnit moveInDir:LP_MOVE_RIGHT];
-			break;
-		case LP_MOVE_FALL:
-			_lockControl = YES;
-			[__currentUnit fallToBottom];
-			break;
-		case LP_MOVE_CW:
-			[__currentUnit rotateCW];
-			break;
-		case LP_MOVE_CCW:
-			[__currentUnit rotateCCW];
-			break;
+  if (_lockControl)
+    {
+      return NO;
+    }
+  if (__currentUnit == nil)
+    {
+      return NO;
+    }
+  switch(dir)
+    {
+    case LP_MOVE_DOWN:
+      return [__currentUnit moveInDir:LP_MOVE_DOWN];
+      break;
+    case LP_MOVE_LEFT:
+      return [__currentUnit moveInDir:LP_MOVE_LEFT];
+      break;
+    case LP_MOVE_RIGHT:
+      return [__currentUnit moveInDir:LP_MOVE_RIGHT];
+      break;
+    case LP_MOVE_FALL:
+      _lockControl = YES;
+      [__currentUnit fallToBottom];
+      break;
+    case LP_MOVE_CW:
+      [__currentUnit rotateCW];
+      break;
+    case LP_MOVE_CCW:
+      [__currentUnit rotateCCW];
+      break;
+    default:
+      NSAssert(0, @"Unreachable");
+      break;
 
-	}
+    }
 
-	[self setNeedsDisplay:YES];
-	return YES;
+  [self setNeedsDisplay:YES];
+  return YES;
 }
 
 -(void) keyDown: (NSEvent *)event
@@ -2153,7 +2176,7 @@ static LPUnit * _random_unit(id owner, int x, int y, BOOL diamond)
 	[self setNeedsDisplay:YES];
 }
 
-- (BOOL) toggleAI
+- (void) toggleAI
 {
 	_useAI = !_useAI;
 }
@@ -2196,7 +2219,7 @@ static LPUnit * _random_unit(id owner, int x, int y, BOOL diamond)
 - (void) addJewelUnit
 {
 	id newUnit = [LPGroupUnit alloc];
-	[newUnit initWithOwner:self
+	newUnit = [newUnit initWithOwner:self
 					 atoms:[NSArray arrayWithObjects:
 						   		_random_unit(newUnit,0,10,YES),
 								_random_unit(newUnit,0,9,NO),nil]];
